@@ -5,9 +5,6 @@ use std::{
     slice::Chunks,
 };
 
-use byteorder::{BigEndian, ByteOrder};
-use git_hash::SIZE_OF_SHA1_DIGEST as SHA1_SIZE;
-
 use crate::{
     file::{self, File, EXTENDED_EDGES_MASK, LAST_EXTENDED_EDGE_MASK, NO_PARENT},
     graph,
@@ -39,17 +36,23 @@ pub struct Commit<'a> {
     root_tree_id: &'a git_hash::oid,
 }
 
+#[inline]
+fn read_u32(b: &[u8]) -> u32 {
+    u32::from_be_bytes(b.try_into().unwrap())
+}
+
 impl<'a> Commit<'a> {
     pub(crate) fn new(file: &'a File, pos: file::Position) -> Self {
         let bytes = file.commit_data_bytes(pos);
         Commit {
             file,
             pos,
-            root_tree_id: git_hash::oid::try_from(&bytes[..SHA1_SIZE]).expect("20 bytes SHA1 to be alright"),
-            parent1: ParentEdge::from_raw(BigEndian::read_u32(&bytes[SHA1_SIZE..SHA1_SIZE + 4])),
-            parent2: ParentEdge::from_raw(BigEndian::read_u32(&bytes[SHA1_SIZE + 4..SHA1_SIZE + 8])),
-            generation: BigEndian::read_u32(&bytes[SHA1_SIZE + 8..SHA1_SIZE + 12]) >> 2,
-            commit_timestamp: BigEndian::read_u64(&bytes[SHA1_SIZE + 8..SHA1_SIZE + 16]) & 0x0003_ffff_ffff,
+            root_tree_id: git_hash::oid::from_bytes_unchecked(&bytes[..file.hash_len]),
+            parent1: ParentEdge::from_raw(read_u32(&bytes[file.hash_len..][..4])),
+            parent2: ParentEdge::from_raw(read_u32(&bytes[file.hash_len + 4..][..4])),
+            generation: read_u32(&bytes[file.hash_len + 8..][..4]) >> 2,
+            commit_timestamp: u64::from_be_bytes(bytes[file.hash_len + 8..][..8].try_into().unwrap())
+                & 0x0003_ffff_ffff,
         }
     }
 
@@ -174,7 +177,7 @@ impl<'a> Iterator for ParentIterator<'a> {
             },
             ParentIteratorState::Extra(mut chunks) => {
                 if let Some(chunk) = chunks.next() {
-                    let extra_edge = BigEndian::read_u32(chunk);
+                    let extra_edge = read_u32(chunk);
                     match ExtraEdge::from_raw(extra_edge) {
                         ExtraEdge::Internal(pos) => {
                             self.state = ParentIteratorState::Extra(chunks);
